@@ -4,7 +4,7 @@ import os
 import re
 import warnings
 from fractions import Fraction
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import Any, Optional, Union
 
 import numpy as np
 import torch
@@ -60,11 +60,11 @@ def write_video(
     video_array: torch.Tensor,
     fps: float,
     video_codec: str = "libx264",
-    options: Optional[Dict[str, Any]] = None,
+    options: Optional[dict[str, Any]] = None,
     audio_array: Optional[torch.Tensor] = None,
     audio_fps: Optional[float] = None,
     audio_codec: Optional[str] = None,
-    audio_options: Optional[Dict[str, Any]] = None,
+    audio_options: Optional[dict[str, Any]] = None,
 ) -> None:
     """
     [DEPRECATED] Writes a 4d tensor in [T, H, W, C] format in a video file.
@@ -117,7 +117,7 @@ def write_video(
     # PyAV does not support floating point numbers with decimal point
     # and will throw OverflowException in case this is not the case
     if isinstance(fps, float):
-        fps = np.round(fps)
+        fps = int(np.round(fps))
 
     with av.open(filename, mode="w") as container:
         stream = container.add_stream(video_codec, rate=fps)
@@ -182,8 +182,8 @@ def _read_from_stream(
     end_offset: float,
     pts_unit: str,
     stream: "av.stream.Stream",
-    stream_name: Dict[str, Optional[Union[int, Tuple[int, ...], List[int]]]],
-) -> List["av.frame.Frame"]:
+    stream_name: dict[str, Optional[Union[int, tuple[int, ...], list[int]]]],
+) -> list["av.frame.Frame"]:
     global _CALLED_TIMES, _GC_COLLECTION_INTERVAL
     _CALLED_TIMES += 1
     if _CALLED_TIMES % _GC_COLLECTION_INTERVAL == _GC_COLLECTION_INTERVAL - 1:
@@ -257,7 +257,7 @@ def _read_from_stream(
 
 
 def _align_audio_frames(
-    aframes: torch.Tensor, audio_frames: List["av.frame.Frame"], ref_start: int, ref_end: float
+    aframes: torch.Tensor, audio_frames: list["av.frame.Frame"], ref_start: int, ref_end: float
 ) -> torch.Tensor:
     start, end = audio_frames[0].pts, audio_frames[-1].pts
     total_aframes = aframes.shape[1]
@@ -277,7 +277,7 @@ def read_video(
     end_pts: Optional[Union[float, Fraction]] = None,
     pts_unit: str = "pts",
     output_format: str = "THWC",
-) -> Tuple[torch.Tensor, torch.Tensor, Dict[str, Any]]:
+) -> tuple[torch.Tensor, torch.Tensor, dict[str, Any]]:
     """[DEPRECATED] Reads a video from a file, returning both the video frames and the audio frames
 
     .. warning::
@@ -401,7 +401,7 @@ def _can_read_timestamps_from_packets(container: "av.container.Container") -> bo
     return False
 
 
-def _decode_video_timestamps(container: "av.container.Container") -> List[int]:
+def _decode_video_timestamps(container: "av.container.Container") -> list[int]:
     if _can_read_timestamps_from_packets(container):
         # fast path
         return [x.pts for x in container.demux(video=0) if x.pts is not None]
@@ -409,7 +409,7 @@ def _decode_video_timestamps(container: "av.container.Container") -> List[int]:
         return [x.pts for x in container.decode(video=0) if x.pts is not None]
 
 
-def read_video_timestamps(filename: str, pts_unit: str = "pts") -> Tuple[List[int], Optional[float]]:
+def read_video_timestamps(filename: str, pts_unit: str = "pts") -> tuple[list[int], Optional[float]]:
     """[DEPREACTED] List the video frames timestamps.
 
     .. warning::
